package Bencher::ScenarioR::AcmePERLANCARTestPerformance;

our $VERSION = 0.05; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        errors     => 2.7e-07,
        modver     => 0.01,
        rate       => 543,
        samples    => 20,
        time       => 1.84,
        vs_slowest => 1,
      },
      {
        errors     => 5.7e-11,
        modver     => 0.02,
        rate       => 2816.48,
        samples    => 20,
        time       => 0.355053,
        vs_slowest => 5.18631,
      },
      {
        errors     => 7.3e-11,
        modver     => 0.03,
        rate       => 4045.69,
        samples    => 20,
        time       => 0.247177,
        vs_slowest => 7.44979,
      },
      {
        errors     => 0,
        modver     => 0.05,
        rate       => 78036.3,
        samples    => 20,
        time       => 0.0128145,
        vs_slowest => 143.697,
      },
      {
        errors     => 6.4e-09,
        modver     => 0.06,
        rate       => 78300,
        samples    => 22,
        time       => 0.0128,
        vs_slowest => 144,
      },
      {
        errors     => 4.8e-09,
        modver     => 0.04,
        rate       => 78400,
        samples    => 38,
        time       => 0.0128,
        vs_slowest => 144,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            include_path => [
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.01",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.02",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.03",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.04",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.05",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.06",
                                            ],
                                            multimodver => "Acme::PERLANCAR::Test::Performance",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "AcmePERLANCARTestPerformance",
                                          },
      "func.bencher_version"           => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 2852.992,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => 2866.828,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 2665.742,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 2684.992,
                                              stepping                     => 4,
                                            },
                                          ],
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__" => 1.034,
                                            "Acme::PERLANCAR::Test::Performance" => 0.06,
                                            "Bencher::Scenario::AcmePERLANCARTestPerformance" => undef,
                                            "Benchmark::Dumb" => "0.10",
                                            "Devel::Platform::Info" => 0.16,
                                            "perl" => "v5.24.0",
                                            "Sys::Info" => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => [
                                            "perl",
                                            ["perl"],
                                            "modver",
                                            [0.04, 0.01, 0.02, 0.06, 0.05, 0.03],
                                            "participant",
                                            [0],
                                            "dataset",
                                            [0],
                                          ],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "rosa",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-3.19.0-32-generic",
                                            kname    => "Linux",
                                            kvers    => "3.19.0-32-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 17.3,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "3.19.0-32-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::AcmePERLANCARTestPerformance",
      "func.scenario_module_md5sum"    => "eb01da751e746c5ce17f469a71cd65fe",
      "func.scenario_module_mtime"     => 1458044421,
      "func.scenario_module_sha1sum"   => "cdcd801414f022536e2d725e930f5b81bdb9396d",
      "func.scenario_module_sha256sum" => "76adffe99901059cabb68a114e612d246729b64c2d1c3287622df53c790227f3",
      "func.time_factor"               => 1000,
      "func.time_start"                => 1485317229.73415,
      "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
      "table.field_units"              => [undef, "/s", "ms"],
      "table.fields"                   => ["modver", "rate", "time", "vs_slowest", "errors", "samples"],
    },
  ],
  [
    200,
    "OK",
    [
      {
        errors => 1.5e-05,
        mod_overhead_time => 3.2,
        modver => 0.06,
        participant => "Acme::PERLANCAR::Test::Performance",
        samples => 20,
        time => 4.9,
        vs_slowest => 1,
      },
      {
        errors => 2e-05,
        mod_overhead_time => 3.1,
        modver => 0.04,
        participant => "Acme::PERLANCAR::Test::Performance",
        samples => 21,
        time => 4.8,
        vs_slowest => 1,
      },
      {
        errors => 2.5e-05,
        mod_overhead_time => 3.1,
        modver => 0.01,
        participant => "Acme::PERLANCAR::Test::Performance",
        samples => 20,
        time => 4.8,
        vs_slowest => 1,
      },
      {
        errors => 3.4e-05,
        mod_overhead_time => 3.1,
        modver => 0.05,
        participant => "Acme::PERLANCAR::Test::Performance",
        samples => 21,
        time => 4.8,
        vs_slowest => 1,
      },
      {
        errors => 2.1e-05,
        mod_overhead_time => 3,
        modver => 0.02,
        participant => "Acme::PERLANCAR::Test::Performance",
        samples => 21,
        time => 4.7,
        vs_slowest => 1.1,
      },
      {
        errors => 4e-05,
        mod_overhead_time => 3,
        modver => 0.03,
        participant => "Acme::PERLANCAR::Test::Performance",
        samples => 20,
        time => 4.7,
        vs_slowest => 1.1,
      },
      {
        errors => 1.1e-05,
        mod_overhead_time => 0,
        modver => "",
        participant => "perl -e1 (baseline)",
        samples => 20,
        time => 1.7,
        vs_slowest => 2.9,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            include_path => [
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.01",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.02",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.03",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.04",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.05",
                                              "/home/u1/repos/perl-Acme-PERLANCAR-Test-Performance/archive/0.06",
                                            ],
                                            module_startup => 1,
                                            multimodver => "Acme::PERLANCAR::Test::Performance",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "AcmePERLANCARTestPerformance",
                                          },
      "func.bencher_version"           => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 2620.953,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => "2861.960",
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 2794.585,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => "2743.070",
                                              stepping                     => 4,
                                            },
                                          ],
      "func.module_startup"            => 1,
      "func.module_versions"           => {
                                            "__PACKAGE__" => 1.034,
                                            "Acme::PERLANCAR::Test::Performance" => 0.06,
                                            "Bencher::Scenario::AcmePERLANCARTestPerformance" => undef,
                                            "Benchmark::Dumb" => "0.10",
                                            "Devel::Platform::Info" => 0.16,
                                            "perl" => "v5.24.0",
                                            "Sys::Info" => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => [
                                            "perl",
                                            ["perl"],
                                            "modver",
                                            [0.02, 0.01, 0.04, 0.06, 0.03, 0.05],
                                            "participant",
                                            [0, 1],
                                          ],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "rosa",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-3.19.0-32-generic",
                                            kname    => "Linux",
                                            kvers    => "3.19.0-32-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 17.3,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "3.19.0-32-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::AcmePERLANCARTestPerformance",
      "func.scenario_module_md5sum"    => "eb01da751e746c5ce17f469a71cd65fe",
      "func.scenario_module_mtime"     => 1458044421,
      "func.scenario_module_sha1sum"   => "cdcd801414f022536e2d725e930f5b81bdb9396d",
      "func.scenario_module_sha256sum" => "76adffe99901059cabb68a114e612d246729b64c2d1c3287622df53c790227f3",
      "func.time_factor"               => 1000,
      "func.time_start"                => 1485317230.64564,
      "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
      "table.field_units"              => [undef, undef, "ms", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "modver",
                                            "time",
                                            "mod_overhead_time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: Benchmark Acme::PERLANCAR::Test::Performance

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

